@@ -20,55 +20,52 @@
 //! This crate provide a priority queue backed by an hashmap
 //! with some efficient methods to change the priority of an element in
 //! **O(log(N))** time (worst case).
-//! 
+//!
 //! The elements (called `Item`s, of type `I`) must implement
 //! [`Hash`](https://doc.rust-lang.org/std/hash/trait.Hash.html)
 //! and [`Eq`](https://doc.rust-lang.org/std/cmp/trait.Eq.html) traits.
-//! 
+//!
 //! The priority `P` may be any type that implements
 //! [`Ord`](https://doc.rust-lang.org/std/cmp/trait.Ord.html).
 //! For reverse order remember the standard wrapper
 //! [`Reverse<T>`](https://doc.rust-lang.org/std/cmp/struct.Reverse.html)
-//! 
+//!
 //! # Example
 //! ```rust
-//! extern crate priority_queue;
-//! 
 //! use priority_queue::PriorityQueue;
-//!       
+//!
 //! fn main() {
 //!     let mut pq = PriorityQueue::new();
-//! 
+//!
 //!     assert!(pq.is_empty());
 //!     pq.push("Apples", 5);
 //!     pq.push("Bananas", 8);
 //!     pq.push("Strawberries", 23);
-//! 
+//!
 //!     assert_eq!(pq.peek(), Some((&"Strawberries", &23)));
-//!     
+//!
 //!     pq.change_priority("Bananas", 25);
 //!     assert_eq!(pq.peek(), Some((&"Bananas", &25)));
-//! 
+//!
 //!     for (item, _) in pq.into_sorted_iter() {
 //!         println!("{}", item);
 //!     }
 //! }
 //! ```
-
-extern crate indexmap;
+#![cfg_attr(feature = "benchmarks", feature(test))]
 #[cfg(all(feature = "serde", test))]
 #[macro_use]
 extern crate serde_derive;
-mod pqueue;
 mod iterators;
-pub use pqueue::PriorityQueue;
+mod pqueue;
+pub use crate::pqueue::PriorityQueue;
 
 #[cfg(test)]
 mod tests {
-    pub use PriorityQueue;
+    pub use crate::PriorityQueue;
 
     #[test]
-    fn init(){
+    fn init() {
         let pq: PriorityQueue<String, i32> = PriorityQueue::new();
         println!("{:?}", pq);
     }
@@ -115,7 +112,7 @@ mod tests {
         assert_eq!(pq.peek(), Some((&"d", &20)));
         assert_eq!(pq.pop(), Some(("d", 20)));
     }
-    
+
     #[test]
     fn change_priority() {
         let mut pq = PriorityQueue::new();
@@ -131,17 +128,76 @@ mod tests {
         assert_eq!(pq.peek(), Some((&"RAM", &11)));
     }
 
+    #[test]
+    fn change_priority_does_not_change_contents() {
+        use std::hash::{Hash, Hasher};
+        struct MyFn {
+            name: &'static str,
+            func: fn(&mut i32),
+        }
+        impl Default for MyFn {
+            fn default() -> Self {
+                Self {
+                    name: "",
+                    func: |_| {},
+                }
+            }
+        }
+        impl PartialEq for MyFn {
+            fn eq(&self, other: &Self) -> bool {
+                self.name == other.name
+            }
+        }
+        impl Eq for MyFn {}
+        impl Hash for MyFn {
+            fn hash<H: Hasher>(&self, state: &mut H) {
+                self.name.hash(state);
+            }
+        }
+        impl std::fmt::Debug for MyFn {
+            fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+                write![f, "{:?}", self.name]
+            }
+        }
+
+        let mut pq = PriorityQueue::new();
+        pq.push(MyFn { name: "increment-one", func: |x| *x += 1 }, 2);
+        pq.push(MyFn { name: "increment-two", func: |x| *x += 2 }, 1);
+
+        let mut cnt = 0;
+        assert_eq![pq.peek(), Some((&MyFn { name: "increment-one", func: |_| {} }, &2))];
+        pq.change_priority(&MyFn { name: "increment-one", func: |_| {} }, 0);
+        assert_eq![pq.peek(), Some((&MyFn { name: "increment-two", func: |_| {} }, &1))];
+
+        assert_eq![cnt, 0];
+
+        (pq.pop().unwrap().0.func)(&mut cnt);
+        assert_eq![cnt, 2];
+
+        (pq.pop().unwrap().0.func)(&mut cnt);
+        assert_eq![cnt, 3];
+    }
+
+    #[test]
+    fn reversed_order() {
+        use std::cmp::Reverse;
+        let mut pq: PriorityQueue<_, Reverse<i32>> = PriorityQueue::new();
+        pq.push("a", Reverse(1));
+        pq.push("b", Reverse(2));
+        assert_eq![pq.pop(), Some(("a", Reverse(1)))];
+    }
+
     #[test]
     fn from_vec() {
-        let v = vec!(("a", 1), ("b", 2), ("f", 7));
+        let v = vec![("a", 1), ("b", 2), ("f", 7)];
         let mut pq = PriorityQueue::from(v);
         assert_eq!(pq.pop(), Some(("f", 7)));
         assert_eq!(pq.len(), 2);
     }
-    
+
     #[test]
     fn from_vec_with_repeated() {
-        let v = vec!(("a", 1), ("b", 2), ("f", 7), ("a", 2));
+        let v = vec![("a", 1), ("b", 2), ("f", 7), ("a", 2)];
         let mut pq = PriorityQueue::from(v);
         assert_eq!(pq.pop(), Some(("f", 7)));
         assert_eq!(pq.len(), 2);
@@ -150,8 +206,8 @@ mod tests {
     #[test]
     fn from_iter() {
         use std::iter::FromIterator;
-        
-        let v = vec!(("a", 1), ("b", 2), ("f", 7));
+
+        let v = vec![("a", 1), ("b", 2), ("f", 7)];
         let mut pq = PriorityQueue::from_iter(v.into_iter());
         assert_eq!(pq.pop(), Some(("f", 7)));
         assert_eq!(pq.len(), 2);
@@ -159,7 +215,7 @@ mod tests {
 
     #[test]
     fn heap_sort() {
-        let v = vec!(("a", 2), ("b", 7), ("f", 1));
+        let v = vec![("a", 2), ("b", 7), ("f", 1)];
         let sorted = (PriorityQueue::from(v)).into_sorted_vec();
         assert_eq!(sorted.as_slice(), &["b", "a", "f"]);
     }
@@ -167,11 +223,11 @@ mod tests {
     #[test]
     fn change_priority_by() {
         use std::iter::FromIterator;
-        
-        let v = vec!(("a", 1), ("b", 2), ("f", 7), ("g", 6), ("h", 5));
+
+        let v = vec![("a", 1), ("b", 2), ("f", 7), ("g", 6), ("h", 5)];
         let mut pq = PriorityQueue::from_iter(v.into_iter());
 
-        pq.change_priority_by("b", |b| b+8);
+        pq.change_priority_by("b", |b| b + 8);
         assert_eq!(pq.into_sorted_vec().as_slice(), &["b", "f", "g", "h", "a"]);
     }
 
@@ -182,11 +238,13 @@ mod tests {
         pq.push("b", 2);
         pq.push("f", 7);
 
-        let v = vec!(("c", 4), ("d", 6), ("e", 3));
+        let v = vec![("c", 4), ("d", 6), ("e", 3)];
         pq.extend(v);
         assert_eq!(pq.len(), 6);
-        assert_eq!(pq.into_sorted_vec().as_slice(),
-                   &["f", "d", "c", "e", "b", "a"]);
+        assert_eq!(
+            pq.into_sorted_vec().as_slice(),
+            &["f", "d", "c", "e", "b", "a"]
+        );
     }
 
     #[test]
@@ -209,7 +267,7 @@ mod tests {
         pq.push("h", 3);
 
         for (i, p) in &mut pq {
-            if *i <"f" {
+            if *i < "f" {
                 *p += 18;
             }
         }
@@ -226,18 +284,20 @@ mod tests {
     }
 
     #[test]
-    fn into_sorted_iter(){
+    fn into_sorted_iter() {
         let mut pq = PriorityQueue::new();
         pq.push("a", 1);
         pq.push("b", 2);
         pq.push("f", 7);
 
-        assert_eq!(pq.into_sorted_iter().collect::<Vec<_>>(),
-                   vec!(("f", 7), ("b", 2), ("a", 1)));
+        assert_eq!(
+            pq.into_sorted_iter().collect::<Vec<_>>(),
+            vec!(("f", 7), ("b", 2), ("a", 1))
+        );
     }
 
     #[test]
-    fn eq(){
+    fn eq() {
         let mut a = PriorityQueue::new();
         let mut b = PriorityQueue::new();
         assert_eq!(a, b);
@@ -260,77 +320,134 @@ mod tests {
         assert_eq!(a, b);
         assert_eq!(b, a);
     }
+
+    #[test]
+    fn non_default_key() {
+        use std::time::*;
+        type PqType = PriorityQueue<i32, Instant>;
+        let _: PqType = PriorityQueue::default();
+    }
+
+    #[cfg(feature = "benchmarks")]
+    extern crate test;
+    #[cfg(feature = "benchmarks")]
+    use test::{black_box, Bencher};
+
+    #[cfg(feature = "benchmarks")]
+    #[bench]
+    fn push_and_pop(b: &mut Bencher) {
+        type PqType = PriorityQueue<usize, i32>;
+        let mut pq: PqType = PriorityQueue::new();
+        b.iter(|| {
+            pq.push(black_box(0), black_box(0));
+            assert_eq![pq.pop().unwrap().1, 0];
+        });
+    }
+
+    //for comparison, using the BinaryHeap
+    #[cfg(feature = "benchmarks")]
+    #[bench]
+    fn push_and_pop_std(b: &mut Bencher) {
+        use std::collections::BinaryHeap;
+        type PqType = BinaryHeap<(usize, i32)>;
+        let mut pq: PqType = BinaryHeap::new();
+        b.iter(|| {
+            pq.push((black_box(0), black_box(0)));
+            assert_eq![pq.pop().unwrap().1, 0];
+        });
+    }
+
+    #[cfg(feature = "benchmarks")]
+    #[bench]
+    fn push_and_pop_on_large_queue(b: &mut Bencher) {
+        type PqType = PriorityQueue<usize, i32>;
+        let mut pq: PqType = PriorityQueue::new();
+        for i in 0..100_000 {
+            pq.push(black_box(i as usize), black_box(i));
+        }
+        b.iter(|| {
+            pq.push(black_box(100_000), black_box(100_000));
+            assert_eq![pq.pop().unwrap().1, black_box(100_000)];
+        });
+    }
+
+    #[cfg(feature = "benchmarks")]
+    #[bench]
+    fn push_and_pop_on_large_queue_std(b: &mut Bencher) {
+        use std::collections::BinaryHeap;
+        type PqType = BinaryHeap<(usize, i32)>;
+        let mut pq: PqType = BinaryHeap::new();
+        for i in 0..100_000 {
+            pq.push((black_box(i as usize), black_box(i)));
+        }
+        b.iter(|| {
+            pq.push((black_box(100_000), black_box(100_000)));
+            assert_eq![pq.pop().unwrap().1, black_box(100_000)];
+        });
+    }
+
 }
 
 #[cfg(all(feature = "serde", test))]
-mod serde_tests_basics{
-    extern crate serde_test;
-    use self::serde_test::{Token, assert_tokens};
-    use ::PriorityQueue;
+mod serde_tests_basics {
+    use serde_test::{assert_tokens, Token};
+    use crate::PriorityQueue;
     #[test]
-    fn serde_empty(){
+    fn serde_empty() {
         let pq: PriorityQueue<String, i32> = PriorityQueue::new();
-        
-        assert_tokens(&pq, &[
-            Token::Seq{len: Some(0)},
-            Token::SeqEnd
-        ]);
+
+        assert_tokens(&pq, &[Token::Seq { len: Some(0) }, Token::SeqEnd]);
     }
 
     #[test]
-    fn serde(){
+    fn serde() {
         let mut pq = PriorityQueue::new();
-        
+
         pq.push("a", 1);
         pq.push("b", 2);
         pq.push("f", 7);
         pq.push("g", 4);
         pq.push("h", 3);
 
-        assert_tokens(&pq, &[
-            Token::Seq{len: Some(5)},
-            Token::Tuple{len:2},
-            Token::BorrowedStr("a"),
-            Token::I32(1),
-            Token::TupleEnd,
-
-            Token::Tuple{len:2},
-            Token::BorrowedStr("b"),
-            Token::I32(2),
-            Token::TupleEnd,
-
-            Token::Tuple{len:2},
-            Token::BorrowedStr("f"),
-            Token::I32(7),
-            Token::TupleEnd,
-
-            Token::Tuple{len:2},
-            Token::BorrowedStr("g"),
-            Token::I32(4),
-            Token::TupleEnd,
-
-            Token::Tuple{len:2},
-            Token::BorrowedStr("h"),
-            Token::I32(3),
-            Token::TupleEnd,
-            Token::SeqEnd
-        ]);
+        assert_tokens(
+            &pq,
+            &[
+                Token::Seq { len: Some(5) },
+                Token::Tuple { len: 2 },
+                Token::BorrowedStr("a"),
+                Token::I32(1),
+                Token::TupleEnd,
+                Token::Tuple { len: 2 },
+                Token::BorrowedStr("b"),
+                Token::I32(2),
+                Token::TupleEnd,
+                Token::Tuple { len: 2 },
+                Token::BorrowedStr("f"),
+                Token::I32(7),
+                Token::TupleEnd,
+                Token::Tuple { len: 2 },
+                Token::BorrowedStr("g"),
+                Token::I32(4),
+                Token::TupleEnd,
+                Token::Tuple { len: 2 },
+                Token::BorrowedStr("h"),
+                Token::I32(3),
+                Token::TupleEnd,
+                Token::SeqEnd,
+            ],
+        );
     }
 }
 
 //more complex tests
 //thanks to ckaran
 #[cfg(all(feature = "serde", test))]
-mod serde_tests_custom_structs{
-    extern crate serde_json;
-    extern crate uuid;
-    extern crate serde;
-
-    use ::PriorityQueue;
-    use std::cmp::{Ord, PartialOrd, Ordering};
+mod serde_tests_custom_structs {
+    use uuid::Uuid;
+    use crate::PriorityQueue;
+    use std::cmp::{Ord, Ordering, PartialOrd};
     use std::default::Default;
     use std::time::Duration;
-    use self::uuid::Uuid;
 
     // Abusing Duration as a mutable std::time::Instant
     type ActivationDate = Duration;
@@ -358,7 +475,7 @@ mod serde_tests_custom_structs{
 
         /// This is a unique ID.  Except for ensuring that different events are
         /// guaranteed to compare as being different, it has no purpose.
-        id: Uuid
+        id: Uuid,
     }
 
     /// Default events activate at time (0, 0)
@@ -368,7 +485,10 @@ mod serde_tests_custom_structs{
     /// create, they will always execute in the same order.
     impl Default for EventComparables {
         fn default() -> Self {
-            EventComparables {activation_date: ActivationDate::new(0,0), id: Uuid::new_v4()}
+            EventComparables {
+                activation_date: ActivationDate::new(0, 0),
+                id: Uuid::new_v4(),
+            }
         }
     }
 
@@ -376,12 +496,13 @@ mod serde_tests_custom_structs{
     /// queue becomes a min-heap instead of a max-heap.
     impl Ord for EventComparables {
         fn cmp(&self, other: &Self) -> Ordering {
-
             // Notice that the we flip the ordering on costs. In case of a tie we
             // compare by id - this step is necessary to make implementations of
             // `PartialEq` and `Ord` consistent.
 
-            other.activation_date.cmp(&self.activation_date)
+            other
+                .activation_date
+                .cmp(&self.activation_date)
                 .then_with(|| self.id.cmp(&other.id))
         }
     }
@@ -403,12 +524,12 @@ mod serde_tests_custom_structs{
     #[derive(Copy, Clone, Eq, PartialEq, Hash, Serialize, Deserialize, Debug)]
     struct ConcreteEvent1 {
         a: i32,
-        b: i64
+        b: i64,
     }
 
     impl Default for ConcreteEvent1 {
         fn default() -> Self {
-            ConcreteEvent1 {a: 0, b: 0}
+            ConcreteEvent1 { a: 0, b: 0 }
         }
     }
 
@@ -460,11 +581,17 @@ mod serde_tests_custom_structs{
         // Create some concrete events and comparables, and test to see that they
         // can be serialized/deserialized
 
-        let ce1 = ConcreteEvent1{a: 12, b: 45};
-        let ec1 = EventComparables {activation_date: ActivationDate::new(0, 1), id: Uuid::new_v4()};
+        let ce1 = ConcreteEvent1 { a: 12, b: 45 };
+        let ec1 = EventComparables {
+            activation_date: ActivationDate::new(0, 1),
+            id: Uuid::new_v4(),
+        };
 
-        let ce2 = ConcreteEvent1{a: 37, b: 123};
-        let ec2 = EventComparables {activation_date: ActivationDate::new(0, 1), id: Uuid::new_v4()};
+        let ce2 = ConcreteEvent1 { a: 37, b: 123 };
+        let ec2 = EventComparables {
+            activation_date: ActivationDate::new(0, 1),
+            id: Uuid::new_v4(),
+        };
 
         let serialized = serde_json::to_string(&ce1).unwrap();
         println!("serialized = {:?}", serialized);
